@@ -69,7 +69,10 @@ CREATE TABLE uaccount (
 GRANT SELECT ON uaccount TO public;
 
 INSERT INTO uaccount
-    VALUES ('regress_rls_alice', 99), ('regress_rls_bob', 1), ('regress_rls_carol', 2), ('regress_rls_dave', 3);
+    VALUES ('regress_rls_alice', 99),
+    ('regress_rls_bob', 1),
+    ('regress_rls_carol', 2),
+    ('regress_rls_dave', 3);
 
 CREATE TABLE category (
     cid int PRIMARY KEY,
@@ -79,7 +82,10 @@ CREATE TABLE category (
 GRANT ALL ON category TO public;
 
 INSERT INTO category
-    VALUES (11, 'novel'), (22, 'science fiction'), (33, 'technology'), (44, 'manga');
+    VALUES (11, 'novel'),
+    (22, 'science fiction'),
+    (33, 'technology'),
+    (44, 'manga');
 
 CREATE TABLE document (
     did int PRIMARY KEY,
@@ -92,7 +98,16 @@ CREATE TABLE document (
 GRANT ALL ON document TO public;
 
 INSERT INTO document
-    VALUES (1, 11, 1, 'regress_rls_bob', 'my first novel'), (2, 11, 2, 'regress_rls_bob', 'my second novel'), (3, 22, 2, 'regress_rls_bob', 'my science fiction'), (4, 44, 1, 'regress_rls_bob', 'my first manga'), (5, 44, 2, 'regress_rls_bob', 'my second manga'), (6, 22, 1, 'regress_rls_carol', 'great science fiction'), (7, 33, 2, 'regress_rls_carol', 'great technology book'), (8, 44, 1, 'regress_rls_carol', 'great manga'), (9, 22, 1, 'regress_rls_dave', 'awesome science fiction'), (10, 33, 2, 'regress_rls_dave', 'awesome technology book');
+    VALUES (1, 11, 1, 'regress_rls_bob', 'my first novel'),
+    (2, 11, 2, 'regress_rls_bob', 'my second novel'),
+    (3, 22, 2, 'regress_rls_bob', 'my science fiction'),
+    (4, 44, 1, 'regress_rls_bob', 'my first manga'),
+    (5, 44, 2, 'regress_rls_bob', 'my second manga'),
+    (6, 22, 1, 'regress_rls_carol', 'great science fiction'),
+    (7, 33, 2, 'regress_rls_carol', 'great technology book'),
+    (8, 44, 1, 'regress_rls_carol', 'great manga'),
+    (9, 22, 1, 'regress_rls_dave', 'awesome science fiction'),
+    (10, 33, 2, 'regress_rls_dave', 'awesome technology book');
 
 ALTER TABLE document ENABLE ROW LEVEL SECURITY;
 
@@ -771,7 +786,16 @@ GRANT ALL ON part_document_satire TO public;
 GRANT ALL ON part_document_nonfiction TO public;
 
 INSERT INTO part_document
-    VALUES (1, 11, 1, 'regress_rls_bob', 'my first novel'), (2, 11, 2, 'regress_rls_bob', 'my second novel'), (3, 99, 2, 'regress_rls_bob', 'my science textbook'), (4, 55, 1, 'regress_rls_bob', 'my first satire'), (5, 99, 2, 'regress_rls_bob', 'my history book'), (6, 11, 1, 'regress_rls_carol', 'great science fiction'), (7, 99, 2, 'regress_rls_carol', 'great technology book'), (8, 55, 2, 'regress_rls_carol', 'great satire'), (9, 11, 1, 'regress_rls_dave', 'awesome science fiction'), (10, 99, 2, 'regress_rls_dave', 'awesome technology book');
+    VALUES (1, 11, 1, 'regress_rls_bob', 'my first novel'),
+    (2, 11, 2, 'regress_rls_bob', 'my second novel'),
+    (3, 99, 2, 'regress_rls_bob', 'my science textbook'),
+    (4, 55, 1, 'regress_rls_bob', 'my first satire'),
+    (5, 99, 2, 'regress_rls_bob', 'my history book'),
+    (6, 11, 1, 'regress_rls_carol', 'great science fiction'),
+    (7, 99, 2, 'regress_rls_carol', 'great technology book'),
+    (8, 55, 2, 'regress_rls_carol', 'great satire'),
+    (9, 11, 1, 'regress_rls_dave', 'awesome science fiction'),
+    (10, 99, 2, 'regress_rls_dave', 'awesome technology book');
 
 ALTER TABLE part_document ENABLE ROW LEVEL SECURITY;
 
@@ -2243,7 +2267,10 @@ CREATE TABLE z2 (
 GRANT SELECT ON z1, z2 TO regress_rls_group1, regress_rls_group2, regress_rls_bob, regress_rls_carol;
 
 INSERT INTO z1
-    VALUES (1, 'aba'), (2, 'bbb'), (3, 'ccc'), (4, 'dad');
+    VALUES (1, 'aba'),
+    (2, 'bbb'),
+    (3, 'ccc'),
+    (4, 'dad');
 
 CREATE POLICY p1 ON z1 TO regress_rls_group1
     USING (a % 2 = 0);
@@ -2567,7 +2594,14 @@ CREATE TABLE x1 (
 GRANT ALL ON x1 TO PUBLIC;
 
 INSERT INTO x1
-    VALUES (1, 'abc', 'regress_rls_bob'), (2, 'bcd', 'regress_rls_bob'), (3, 'cde', 'regress_rls_carol'), (4, 'def', 'regress_rls_carol'), (5, 'efg', 'regress_rls_bob'), (6, 'fgh', 'regress_rls_bob'), (7, 'fgh', 'regress_rls_carol'), (8, 'fgh', 'regress_rls_carol');
+    VALUES (1, 'abc', 'regress_rls_bob'),
+    (2, 'bcd', 'regress_rls_bob'),
+    (3, 'cde', 'regress_rls_carol'),
+    (4, 'def', 'regress_rls_carol'),
+    (5, 'efg', 'regress_rls_bob'),
+    (6, 'fgh', 'regress_rls_bob'),
+    (7, 'fgh', 'regress_rls_carol'),
+    (8, 'fgh', 'regress_rls_carol');
 
 CREATE POLICY p0 ON x1
     FOR ALL
@@ -2788,7 +2822,8 @@ CREATE TABLE test_qual_pushdown (
 );
 
 INSERT INTO test_qual_pushdown
-    VALUES ('abc'), ('def');
+    VALUES ('abc'),
+    ('def');
 
 SELECT
     *
@@ -3098,10 +3133,19 @@ CREATE POLICY blog_1 ON blog
 ALTER TABLE blog ENABLE ROW LEVEL SECURITY;
 
 INSERT INTO blog
-    VALUES (1, 'alice', 'blog #1'), (2, 'bob', 'blog #1'), (3, 'alice', 'blog #2'), (4, 'alice', 'blog #3'), (5, 'john', 'blog #1');
+    VALUES (1, 'alice', 'blog #1'),
+    (2, 'bob', 'blog #1'),
+    (3, 'alice', 'blog #2'),
+    (4, 'alice', 'blog #3'),
+    (5, 'john', 'blog #1');
 
 INSERT INTO comment
-    VALUES (1, 'cool blog'), (1, 'fun blog'), (3, 'crazy blog'), (5, 'what?'), (4, 'insane!'), (2, 'who did it?');
+    VALUES (1, 'cool blog'),
+    (1, 'fun blog'),
+    (3, 'crazy blog'),
+    (5, 'what?'),
+    (4, 'insane!'),
+    (2, 'who did it?');
 
 SET SESSION AUTHORIZATION regress_rls_bob;
 
@@ -3493,7 +3537,10 @@ CREATE TABLE current_check (
 GRANT ALL ON current_check TO PUBLIC;
 
 INSERT INTO current_check
-    VALUES (1, 'abc', 'regress_rls_bob'), (2, 'bcd', 'regress_rls_bob'), (3, 'cde', 'regress_rls_bob'), (4, 'def', 'regress_rls_bob');
+    VALUES (1, 'abc', 'regress_rls_bob'),
+    (2, 'bcd', 'regress_rls_bob'),
+    (3, 'cde', 'regress_rls_bob'),
+    (4, 'def', 'regress_rls_bob');
 
 CREATE POLICY p1 ON current_check
     FOR SELECT
@@ -3813,10 +3860,12 @@ CREATE TABLE r2 (
 );
 
 INSERT INTO r1
-    VALUES (10), (20);
+    VALUES (10),
+    (20);
 
 INSERT INTO r2
-    VALUES (10), (20);
+    VALUES (10),
+    (20);
 
 GRANT ALL ON r1, r2 TO regress_rls_bob;
 
@@ -3929,7 +3978,8 @@ CREATE TABLE r1 (
 );
 
 INSERT INTO r1
-    VALUES (10), (20);
+    VALUES (10),
+    (20);
 
 CREATE POLICY p1 ON r1
     USING (FALSE);
@@ -3988,10 +4038,12 @@ CREATE TABLE r2 (
 );
 
 INSERT INTO r1
-    VALUES (10), (20);
+    VALUES (10),
+    (20);
 
 INSERT INTO r2
-    VALUES (10), (20);
+    VALUES (10),
+    (20);
 
 -- Create policies on r2 which prevent the
 -- owner from seeing any rows, but RI should
@@ -4045,10 +4097,12 @@ CREATE TABLE r2 (
 );
 
 INSERT INTO r1
-    VALUES (10), (20);
+    VALUES (10),
+    (20);
 
 INSERT INTO r2
-    VALUES (10), (20);
+    VALUES (10),
+    (20);
 
 -- Create policies on r2 which prevent the
 -- owner from seeing any rows, but RI should
@@ -4084,10 +4138,12 @@ CREATE TABLE r2 (
 );
 
 INSERT INTO r1
-    VALUES (10), (20);
+    VALUES (10),
+    (20);
 
 INSERT INTO r2
-    VALUES (10), (20);
+    VALUES (10),
+    (20);
 
 -- Create policies on r2 which prevent the
 -- owner from seeing any rows, but RI should
@@ -4142,7 +4198,8 @@ ALTER TABLE r1 FORCE ROW LEVEL SECURITY;
 
 -- Works fine
 INSERT INTO r1
-    VALUES (10), (20);
+    VALUES (10),
+    (20);
 
 -- No error, but no rows
 TABLE r1;
@@ -4156,7 +4213,8 @@ SET row_security = ON;
 
 -- Error
 INSERT INTO r1
-    VALUES (10), (20)
+    VALUES (10),
+    (20)
 RETURNING
     *;
 
