@@ -296,7 +296,8 @@ FOR VALUES IN (1) ON COMMIT DELETE ROWS;
 CREATE temp TABLE temp_parted_oncommit_test2 PARTITION OF temp_parted_oncommit_test
 FOR VALUES IN (2) ON COMMIT DROP;
 INSERT INTO temp_parted_oncommit_test
-    VALUES (1), (2);
+    VALUES (1),
+    (2);
 COMMIT;
 
 -- no relations remain in this case.
@@ -319,7 +320,8 @@ FOR VALUES IN (1) ON COMMIT preserve ROWS;
 CREATE temp TABLE temp_parted_oncommit_test2 PARTITION OF temp_parted_oncommit_test
 FOR VALUES IN (2) ON COMMIT DROP;
 INSERT INTO temp_parted_oncommit_test
-    VALUES (1), (2);
+    VALUES (1),
+    (2);
 COMMIT;
 
 -- Data from the remaining partition is still here as its rows are
